import { forwardRef, useEffect, useRef, useState } from 'react';

export default forwardRef(function InputPassword({ isFocused = false, className = '', ...props }, ref) {
    const input = ref ? ref : useRef();

    const [showPassword, setShowPassword] = useState(false);

    const handleToggleShowPassword = () => {
        setShowPassword(!showPassword);
    };

    useEffect(() => {
        if (isFocused) input.current.focus();
    }, []);

    return (
        <div className="relative w-full">
            <input
                className={`rounded-lg py-[4px] border border-border focus:border-border focus:ring-border lg:text-[.8rem] sm:text-lg bg-background-secondary w-full ${className}`}
                placeholder="············"
                type={showPassword ? 'text' : 'password'}
                {...props}
            />

            <button type="button" className="absolute right-2 top-2 lg:top-[5px] text-text-primary hover:text-text-white focus:outline-none" onClick={handleToggleShowPassword}>
                <i className={showPassword ? 'bi bi-eye-slash text-lg' : 'bi bi-eye text-lg'}></i>
            </button>
        </div>
    );
});